local gr = love.graphics
io.stdout:setvbuf( 'no' )

function love.load()
	eye = {
		open	= gr.newImage( 'eyes.jpg' ),
		closed	= gr.newImage( 'closed.jpg' ),
		size	= { x = 1, y = 1 },		-- adjusts display size
		quads	= {},
		order	= { r = {2,3,4,1}, l = {2,1,4,3} }
		}
	gr.setBackgroundColor( 149, 125, 105 )
	sprite		= {
		w		= eye.closed:getWidth()+1,
		h		= eye.closed:getHeight(),
		mx		= eye.open:getWidth(),
		my		= eye.open:getHeight()
		}
	screen		= { w = 3 * sprite.w * eye.size.x, h = sprite.h * eye.size.y }
	love.window.setMode( screen.w, screen.h, {borderless=true} )
	eye.x		= sprite.w * eye.size.x
	eye.y		= 0
	for i = 0, 3 do eye.quads[i+1] = gr.newQuad(i*sprite.w,0,sprite.w,sprite.h,sprite.mx,sprite.my) end
	eye.draw	= function( s )
		if s ~= 0 then
			gr.draw( eye.open, eye.quads[eye.order.r[s]], eye.x, eye.y, 0, eye.size.x, eye.size.y )
			gr.draw( eye.open, eye.quads[eye.order.l[s]], eye.x,-eye.y, 0,-eye.size.x, eye.size.y )
			else
			gr.draw( eye.closed, eye.x, eye.y, 0, eye.size.x, eye.size.y )
			gr.draw( eye.closed, eye.x, eye.y, 0,-eye.size.x, eye.size.y )
			end
		end
	cntX		= screen.w/2 + sprite.w * eye.size.x	-- location of controls
	cntY		= screen.h/2
	controls	= selector( 'eyes', cntX, cntY, {'N','E','S','W'} )
	mode		= 'hover'		-- or 'click'
	keyResponse = {	-- could use loadstring - but slower
		escape	= function() love.event.push( 'quit' ) end,
		h		= function() mode = 'hover'	end,
		c		= function() mode = 'click'	end,
		n		= function() mode = ''		end}
	end

function love.draw()
	sel = controls( mode )
	gr.setColor( 255, 255, 255 )
	eye.draw( sel )
	gr.rectangle( 'line', 5, 5, screen.w-10, screen.h-10 )
	end

function love.keypressed( key )
	if keyResponse[key] then keyResponse[key]() end
	end

-- could create a table version using Selector.init and Selector.draw
-- this version uses a closure function
function selector( name, x, y, opt )
	local selected	= 0
	local font 		= gr.getFont()
	local radius	= font:getHeight()		-- button radius
	local Radius	= radius * #opt/2		-- radius of all button's display
	local an		= 2 * math.pi / #opt	-- angle between buttons
	local data		= {}
	for i = 0, #opt-1 do
		data[i+1] = {
			Radius * math.cos( an*i - math.pi/2 ) + x,
			Radius * math.sin( an*i - math.pi/2 ) + y
			}
		end
	local textOffsets	= function( text )	-- for centering text
		return  { x = -font:getWidth(text)/2, y = -font:getHeight(text)/2 }
		end
	local mouseOver		= function( x, y, r )			-- within radius of point
		local mx, my	= love.mouse.getPosition( )
		local dis		= ( mx-x )^2 + ( my-y )^2	-- avoids sqrt call
		return dis < r*r
		end
	return function( mode )	-- closure function ( avoids repeating cos, sin & pi )
		if mode ~= 'hover'  and mode ~= 'click' then return selected or 0 end
		if mode == 'hover' then selected = 0 end
		for i = 1, #data do
			local of = textOffsets( opt[i] )
			local X, Y = data[i][1], data[i][2]
			gr.circle( 'line', X, Y, radius )
			gr.print( opt[i], X+of.x, Y+of.y )
			if mouseOver( X, Y, radius ) then
				if mode == 'hover' then selected = i
					else
					if love.mouse.isDown( 1 ) then selected = i end
					end
				end
			if mouseOver( x, y, radius ) and love.mouse.isDown(1) and mode=='click' then selected = 0 end
			end
		local of = textOffsets( name )
		gr.print( name, x+of.x, y+of.y )
		if selected ~= 0 then		-- point to selected option
			gr.setColor( 0, 255, 0 )
			gr.circle( 'line', data[selected][1], data[selected][2], radius )
			end
		return selected
		end
	end
